#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Wed Jun  9 17:26:27 2021

@author: jotape42p
"""

units_def = {
    'm3': 'm3 = m**3',
    'm2': 'm2 = m**2',
    
    # Dimensionless
    'point score': 'point_score = [point_score]',
    'score': 'score = [score]',
    'guest night': 'guest_night = item', # = [guest_night]', Otherwise it is not possible to convert
    'PMH': 'PMH = [PMH]',

    # Item
    'dozen': 'dozen = 12 * item = _ = Dozen = Dozens',
    'person': 'person = item',
    'seedling': 'seedling = item',
    'head': 'head = item',
    'unit': 'unit = item',

    # Energy
    'mj': 'mj = megajoule',
    'OLD_MJ': 'OLD_MJ = 1e6 * joule',
    'kilocalorie_thermochemical': 'kilocalorie_thermochemical = 1e3 * calorie',
    'calorie_thermochemical': 'calorie_thermochemical = calorie',
    'kilocalorie_ISO_IT': 'kilocalorie_ISO_IT = 1e3 * calorie',
    'British_thermal_unit_thermochemical': 'British_thermal_unit_thermochemical = BTU_th',
    'British_thermal_unit_ISO_IT': 'British_thermal_unit_ISO_IT = BTU_it',
    'therm_EC': 'therm_EC = 1.05506e8 * joule', # ecoinvent metadata
    'therm_US': 'therm_US = 1.054804e8 * joule', # ecoinvent metadata
    'calorie_59_degree_F': 'calorie_59_degree_F = 4.1858 * joule',
    'calorie_ISO_IT': 'calorie_ISO_IT = calorie',
    'British_thermal_unit_59_degree_F': 'British_thermal_unit_59_degree_F = 0.0010548 * megajoule',
    'barrel_of_oil_energy_equivalent_59_degree_F': 'barrel_of_oil_energy_equivalent_59_degree_F = 0.00611784 * megajoule',
    'barrel_of_oil_energy_equivalent_ISO_IT': 'barrel_of_oil_energy_equivalent_ISO_IT = 6119.323945196 * megajoule',
    'ton_of_oil_energy_equivalent_thermochemical': 'ton_of_oil_energy_equivalent_thermochemical = 44768.8 * megajoule',
    'ton_of_oil_energy_equivalent_ISO_IT': 'ton_of_oil_energy_equivalent_ISO_IT = tonne_of_oil_equivalent',
    'megaton_of_oil_energy_equivalent_ISO_IT': 'megaton_of_oil_energy_equivalent_ISO_IT = 1e6 * tonne_of_oil_equivalent',
    'gigaton_of_oil_energy_equivalent_ISO_IT': 'gigaton_of_oil_energy_equivalent_ISO_IT = 1e9 * tonne_of_oil_equivalent',
    'foot_poundal': 'foot_poundal = 4.21401100938048e-2 * joule', # ecoinvent metadata
    'foot_pound_force': 'foot_pound_force = 1.3558179483314 * joule', # ecoinvent metadata

    # Percentage
    'percent': 'percent = 1e-2 * frac = pct = %',

    # Mass
    'kilogram_NH3_N': 'kilogram_NH3_N = 1e3 * gram = kg_NH3_N',
    'kilogram_N2O_N': 'kilogram_N2O_N = 1e3 * gram = kg_N2O_N',
    'kilogram_NO3_N': 'kilogram_NO3_N = 1e3 * gram = kg_NO3_N',
    'kilogram_NOx': 'kilogram_NOx = 1e3 * gram = kg_NOx',
    'kilogram_N2O': 'kilogram_N2O = 1e3 * gram = kg_N2O',
    'kilogram_N': 'kilogram_N = 1e3 * gram = kg_N',
    'kilogram_PO4': 'kilogram_PO4 = 1e3 * gram = kg_PO4',
    'kilogram_P2O5': 'kilogram_P2O5 = 1e3 * gram = kg_P2O5',
    'kilogram_vehicle': 'kilogram_vehicle = 1e3 * gram = kg_vehicle',
    'Eq': 'Eq = gram',
    'pound_avoirdupois': 'pound_avoirdupois = avoirdupois_pound',
    'ounce_avoirdupois': 'ounce_avoirdupois = avoirdupois_ounce',
    'barrel_lime_small_mass_equivalent': 'barrel_lime_small_mass_equivalent = 81.6466266 * kilogram',
    'barrel_lime_large_mass_equivalent': 'barrel_lime_large_mass_equivalent = 127.0058636 * kilogram',
    'troy_grain': 'troy_grain = grain',
    'metric_grain': 'metric_grain = 5e-2 * gram',
    'short_assay_ton': 'short_assay_ton = 29.166666666667 * gram',
    'micro_gram': 'micro_gram = microgram',
    
    # Mass / area * time
    'kilogram_P': 'kilogram_P = 1e3 * gram = kg_P',
    'kilogram_P_per_hectare_year': 'kilogram_P_per_hectare_year = 1e3 * gram / (hectare * year) = kg_P/(ha*year)',
    
    # Photovoltaic yield
    'kilowatt_hour_potential': 'kilowatt_hour_potential = 1e3 * watt = kWp',
    'photovoltaic_yield': 'photovoltaic_yield = 1e3 * watt_hour / kWp',
    
    # Volume
    'TEU': 'TEU = 38.5 * meter ** 3',
    'gallon_fluid_US': 'gallon_fluid_US = US_liquid_gallon',
    'barrel_fluid_US': 'barrel_fluid_US = US_fluid_barrel',
    'barrel_dry': 'barrel_dry = US_dry_barrel',
    'gallon_dry_US': 'gallon_dry_US = US_dry_gallon',
    'quart_fluid_US': 'quart_fluid_US = US_liquid_quart',
    'quart_dry_US': 'quart_dry_US = US_dry_quart',
    'pint_dry_US': 'pint_dry_US = US_dry_pint',
    'pint_fluid_US': 'pint_fluid_US = US_liquid_pint',
    'ounce_fluid_US': 'ounce_fluid_US = US_liquid_ounce',
    'barrel_beer_US': 'barrel_beer_US = beer_barrel',
    'bushel_US': 'bushel_US = bushel',
    'gallon_Imperial': 'gallon_Imperial = UK_gallon',
    'quart_Imperial': 'quart_Imperial = UK_quart',
    'pint_Imperial': 'pint_Imperial = UK_pint',
    'barrel_fluid_Imperial': 'barrel_fluid_Imperial = UK_barrel',
    'cord': 'cord = 3.62456 * meter ** 3',
    'barrel_oil': 'barrel_oil = oil_barrel',
    'survey_acre_foot': 'survey_acre_foot = acre_foot',
    'barrel_cranberry': 'barrel_cranberry = 0.095471034864 * meter ** 3',
    
    # Density
    'ounce_avoirdupois_per_gallon_Imperial': 'ounce_avoirdupois_per_gallon_Imperial = avoirdupois_ounce / UK_gallon',
    'pound_per_cubic_yard': 'pound_per_cubic_yard = pound / yard ** 3',
    'pound_per_cubic_foot': 'pound_per_cubic_foot = pound / foot ** 3',
    'pound_per_cubic_inch': 'pound_per_cubic_inch = pound / inch ** 3',
    'ounce_avoirdupois_per_cubic_inch': 'ounce_avoirdupois_per_cubic_inch = avoirdupois_ounce / inch ** 3',
    'short_ton_per_cubic_yard': 'short_ton_per_cubic_yard = short_ton / yard ** 3',
    'pound_per_gallon_Imperial': 'pound_per_gallon_Imperial = pound / UK_gallon',
    'long_ton_per_cubic_yard': 'long_ton_per_cubic_yard = long_ton / yard ** 3',
    
    # Temperature
    'degree_F': 'degree_F = degreeF',
    
    # Thermal insulance
    'clo': 'clo = 1.55e-1 * kelvin * meter ** 2 / watt',
    'tog': 'tog = 0.1 * kelvin * meter ** 2 / watt',
    
    # Area
    'survey_acre': 'survey_acre = acre',
    
    # Mass * length
    'kgkm': 'kgkm = kilogram * kilometer',
    
    # Luminance
    'foot_candle': 'foot_candle = 10.7639104167097 * lux',
    
    # Radioactivity
    'kbq': 'kbq = kBq',

    # Market value, bulk price
    'CHF2011': 'CHF2011 = 0.746 * EUR_default',
    'EUR2000': 'EUR2000 = 1.11 * EUR_default',
    'EUR2005basic': 'EUR2005basic = 1 * EUR_default',
    'USD2011': 'USD2011 = 0.631 * EUR_default'
    }

pint_to_ilcd_def = {
    '329b50e2-c594-39e9-953c-04c61d81d61e': ('1acf7c0f-aa9d-4022-a4b7-fe0b54ea0b91','Items*a','item*a'),
    '60a18d85-9c22-3f47-b932-2447513880c9': ('5beb6eed-33a9-47b8-9ede-1dfe8f679159','Item(s)','item'),
    'f09fb2f1-8af1-3630-8463-c7ebc26474be': ('93a60a57-a3c8-11da-a746-0800200c9a66','MJ','MJ'), # Considered as energy
    '5f4bed1b-40a0-39cd-9fbe-798c54c5d5a5': ('93a60a57-a3c8-12da-a746-0800200c9a66','m3','m**3'),
    '9441711e-e3ae-36cd-bfaf-83783500857f': ('838aaa21-0117-11db-92e3-0800200c9a66','t*km','t*km'),
    '40c11086-1e24-3103-8226-47fc3d6f8d57': ('838aaa22-0117-11db-92e3-0800200c9a66','m','m'),
    'e132038d-01c0-35ce-a697-b8892ced1280': ('5454b231-270e-45e6-89b2-7f4f3e482245','Items*km','item*km'), # NOT
    'd5b44662-691e-39e9-b139-c306815ffd72': ('93a60a57-a3c8-16da-a746-0800200c9a66','kBq','kBq'),
    '98c1db98-9766-3362-8e79-aedf42522267': ('93a60a57-a3c8-18da-a746-0800200c9a66','m2','m**2'),
    '174a2f50-251e-374d-81c7-088f905c30cd': ('93a60a57-a3c8-20da-a746-0800200c9a66','m2*a','m**2*a'),
    '080aba62-dce7-313f-a6f1-2d94db4d5a97': ('93a60a57-a3c8-23da-a746-0800200c9a66','m3*a','m**3*a'),
    '7844486d-bbaf-3c45-9487-7fe3476c5b6f': ('93a60a57-a4c8-11da-a746-0800200c9a66','kg','kg'),
    '5f5fa142-2703-39f2-bf19-ff33f435cc49': ('af638906-3ec7-4314-8de7-f76039f2dd01','d','day'),
    'e2c902a8-5a87-34ea-b6cb-f9579afa41f9': ('b4cac580-5ce8-11df-a08a-0800200c9a66','m*a','m*a'), # NOT
    'ca2f7f9a-ae4e-3c80-9388-b7bc26a8bf4d': ('f170abd3-f010-45f4-8e7c-9871a5c0421b','mol','mol'),
    '371b6515-6488-399b-9364-b9125dcf5ef2': ('ff8ed45d-bbfb-4531-8c7b-9b95e52bd41d','m3*km','m**3*km'),
    '7cd6e908-4c0a-35b9-9530-620e5877f4e5': ('da299c4d-1741-4da8-9fbd-5ccfb5e1d688','EUR2000','EUR2000'), # NOT
    '86e381c9-d6d4-3241-b8f6-3d78596aa3cc': ('59f191d6-5dd3-4553-af88-1a32accfe308','kg*a','kg*a'), # NOT
    }

# Dict with keys being uuid bound to a pint dimensionality or property id and value equal to 
#   the default uuid of their flow property [GaBi additions not considered, only ILCD entries]

pint_to_ilcd_fp = {
    '60a18d85-9c22-3f47-b932-2447513880c9': ('01846770-4cfe-4a25-8ad9-919d8d378345','5beb6eed-33a9-47b8-9ede-1dfe8f679159','Item(s)','03.00.004','Number of items'),
    'f09fb2f1-8af1-3630-8463-c7ebc26474be': ('93a60a56-a3c8-11da-a746-0800200c9a66','93a60a57-a3c8-11da-a746-0800200c9a66','MJ','03.00.003','Net calorific value'), # NET
    'f09fb2f1-8af1-3630-8463-c7ebc26474bf': ('93a60a56-a3c8-14da-a746-0800200c9a66','93a60a57-a3c8-11da-a746-0800200c9a66','MJ','03.00.003','Gross calorific value'), # GROSS
    '5f4bed1b-40a0-39cd-9fbe-798c54c5d5a5': ('93a60a56-a3c8-22da-a746-0800200c9a66','93a60a57-a3c8-12da-a746-0800200c9a66','m3','03.00.003','Volume'),
    '9441711e-e3ae-36cd-bfaf-83783500857f': ('838aaa20-0117-11db-92e3-0800200c9a66','838aaa21-0117-11db-92e3-0800200c9a66','t*km','03.00.000','Goods transport (mass*distance)'),
    '40c11086-1e24-3103-8226-47fc3d6f8d57': ('838aaa23-0117-11db-92e3-0800200c9a66','838aaa22-0117-11db-92e3-0800200c9a66','m','03.00.000','Length'),
    'e132038d-01c0-35ce-a697-b8892ced1280': ('1cc347a0-3bd1-46db-a308-2707c68d2351','5454b231-270e-45e6-89b2-7f4f3e482245','Items*km','03.00.000','Person transport'),
    'd5b44662-691e-39e9-b139-c306815ffd72': ('93a60a56-a3c8-17da-a746-0800200c9a66','93a60a57-a3c8-16da-a746-0800200c9a66','kBq','03.00.003','Radioactivity'),
    '98c1db98-9766-3362-8e79-aedf42522267': ('93a60a56-a3c8-19da-a746-0800200c9a66','93a60a57-a3c8-18da-a746-0800200c9a66','m2','03.00.003','Area'),
    '174a2f50-251e-374d-81c7-088f905c30cd': ('93a60a56-a3c8-21da-a746-0800200c9a66','93a60a57-a3c8-20da-a746-0800200c9a66','m2*a','03.00.003','Area*time'),
    '080aba62-dce7-313f-a6f1-2d94db4d5a97': ('441238a3-ba09-46ec-b35b-c30cfba746d1','93a60a57-a3c8-23da-a746-0800200c9a66','m3*a','02.00.003','Volume*time'),
    '7844486d-bbaf-3c45-9487-7fe3476c5b6f': ('93a60a56-a3c8-11da-a746-0800200b9a66','93a60a57-a4c8-11da-a746-0800200c9a66','kg','03.00.003','Mass'),
    '5f5fa142-2703-39f2-bf19-ff33f435cc49': ('c0447923-0e60-4b3c-97c2-a86dddd9eea5','af638906-3ec7-4314-8de7-f76039f2dd01','d','03.00.000','Duration'),
    'e2c902a8-5a87-34ea-b6cb-f9579afa41f9': ('e07b4169-bd86-4337-8fa6-1f76916475bf','b4cac580-5ce8-11df-a08a-0800200c9a66','m*a','02.00.000','Length*time'),
    '7cd6e908-4c0a-35b9-9530-620e5877f4e5': ('67b63204-ef91-44b2-a927-2f4ead1fae17','da299c4d-1741-4da8-9fbd-5ccfb5e1d688','EUR2000','03.00.000','Currency'),
    '86e381c9-d6d4-3241-b8f6-3d78596aa3cc': ('b3f0f892-c5a3-4c66-a432-c09e3d1e9bd6','59f191d6-5dd3-4553-af88-1a32accfe308','kg*a','03.00.003','Mass*time'),
    
    '38f94dd1-d5aa-41b8-b182-c0c42985d9dc': ('67b63204-ef91-44b2-a927-2f4ead1fae17','da299c4d-1741-4da8-9fbd-5ccfb5e1d688','03.00.000','price'),
    '7a3978ea-3e26-4329-bc8b-0915d58a7e6f': ('67b63204-ef91-44b2-a927-2f4ead1fae17','da299c4d-1741-4da8-9fbd-5ccfb5e1d688','03.00.000','true value relation'),
    '6bc8ac5e-cc4c-45fb-93dc-53c0e45091df': ('93a60a56-a3c8-14da-a746-0800200c9a66','93a60a57-a3c8-11da-a746-0800200c9a66','03.00.003','energy content'),
    'd61b8768-8ef6-4a99-ae16-9e51f24ad5b5': ('93a60a56-a3c8-14da-a746-0800200c9a66','93a60a57-a3c8-11da-a746-0800200c9a66','03.00.003','heating value, gross'),
    '48c987bb-3144-4872-b5c7-b1389c40be25': ('93a60a56-a3c8-11da-a746-0800200c9a66','93a60a57-a3c8-11da-a746-0800200c9a66','03.00.003','heating value, net'),
    'ed229b01-1b3f-4754-8871-5e88a83f3725': ('f2149ae0-b105-4299-b1f1-cf1fd1577867','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','concentration, chromium'),
    'bca4bb32-f701-46bb-ba1e-bad477c19f7f': ('f2149ae0-b105-4299-b1f1-cf1fd1577867','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, chromium'),
    'e1d2c19b-3a97-4f52-a83f-fe88400452c2': ('f2149ae0-b105-4299-b1f1-cf1fd1577867','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','chromium content'),
    '35d16e49-9e29-4e1d-ac22-ea7f84fb76e1': ('ac557972-7563-49fb-8461-29a4fe8600b7','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, gallium'),
    'a17f5864-6177-4619-82c5-3426c8c64e7d': ('ac557972-7563-49fb-8461-29a4fe8600b7','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','gallium content'),
    '2f7030b9-bafc-4b43-8504-deb8b5044130': ('b1192e5a-4a70-4fd7-89a2-6b798c7ed3a7','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, cobalt'),
    '66e996b5-5f7b-449f-8893-0b787af21d7e': ('b1192e5a-4a70-4fd7-89a2-6b798c7ed3a7','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','cobalt content'),
    'd574cc22-07f2-4202-b564-1116ab197692': ('a5278d68-2936-477b-b9de-7ad2d66422ec','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, strontium'),
    '995265a2-f2cb-4c12-a961-766eb34392b9': ('a5278d68-2936-477b-b9de-7ad2d66422ec','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','strontium content'),
    '1325d7f9-2fe2-4226-9304-ad9e5371e08f': ('dd77d131-c2ee-4d5a-b5d3-f7aa981ae305','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, scandium'),
    '35d2e0b2-eca5-4897-a6af-b6d2e61a9079': ('dd77d131-c2ee-4d5a-b5d3-f7aa981ae305','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','scandium content'),
    '3759d833-560a-4dbb-949e-afc63c0ade26': ('435e1d0e-e36e-4d4a-9cd1-7fd2c135da61','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, antimony'),
    '4054bfa7-dfcb-452e-b1dd-810b9e981506': ('435e1d0e-e36e-4d4a-9cd1-7fd2c135da61','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','antimony content'),
    'a7e81e5c-d3b9-421c-bf6f-7cafcf911ab7': ('c2a5d679-93be-44a1-b82f-da986e622ab9','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, europium'),
    '0b27405b-3e4d-45aa-bb5c-3c52d2b04e0e': ('c2a5d679-93be-44a1-b82f-da986e622ab9','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','europium content'),
    'd33e6732-d2f8-4441-ba03-e39d4a1228a5': ('7eb6e3cb-0c12-4216-99b5-2032906d42ca','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration. lanthanum'),
    '94b2be61-35f2-40fb-b9ab-636ae5a0415b': ('7eb6e3cb-0c12-4216-99b5-2032906d42ca','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','lanthanum content'),
    'a301a838-7975-4d89-9e74-8eb77ad03cd1': ('fec15e58-109a-4775-bc6f-72ca0b9b3cee','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','carbon content'),
    'd388e0ab-8411-4347-8174-c5bf5fd14296': ('fec15e58-109a-4775-bc6f-72ca0b9b3cee','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, carbone dioxide'), # Typo in name
    'c74c3729-e577-4081-b572-a283d2561a75': ('64b8e725-b0ba-4837-abb9-62dc0e7b9f6f','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','carbon content, fossil'),
    '6393c14b-db78-445d-a47b-c0cb866a1b25': ('62e503ce-544a-4599-b2ad-bcea15a7bf20','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','carbon content, non-fossil'),
    '883a9dc6-bbb5-418c-8d6e-7031e96028ef': ('62e503ce-544a-4599-b2ad-bcea15a7bf20','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','organic carbon content'),
    '044617f2-c1d4-4592-94c6-bb325139e231': ('62e503ce-544a-4599-b2ad-bcea15a7bf20','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','Organic Carbon content of soil'),
    '1ced5983-2a7b-49af-b6cd-ad4ebaafba89': ('b539c404-ce19-43fb-ba14-6a1bdd46d8be','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, praseodymium'), # used ILCD Praseodym content
    '4fb17587-2c03-4b4e-b38b-867cfd4bfae8': ('b539c404-ce19-43fb-ba14-6a1bdd46d8be','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','praseodymium content'), # used ILCD Praseodym content
    'cea619b8-1a76-4680-8b55-cdf682a3b32a': ('76d611d0-a0a5-43d5-b391-a4e7ec463052','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','concentration, calcium'),
    'ddbab0d1-b156-41bc-98e5-fb680285d7cd': ('76d611d0-a0a5-43d5-b391-a4e7ec463052','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, calcium'),
    'f9da385d-5b1b-4548-826c-0bf5892a9fd9': ('76d611d0-a0a5-43d5-b391-a4e7ec463052','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','calcium content'),
    '468e50e8-1960-4eba-bc1a-a9938a301694': ('984505b9-8536-4e31-a312-0d1a3788f009','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, chlorine'),
    '66d4c921-658a-4ba0-b190-c6e09e57d74a': ('984505b9-8536-4e31-a312-0d1a3788f009','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','chlorine content'),
    'f0e05731-4b64-4a8a-a216-a7ad908d76bc': ('3da87ad0-733e-4ca9-b234-75ef52ca2a2d','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, holmium'),
    '86937b4e-c531-4ce5-b65e-ce0d17d3ca27': ('3da87ad0-733e-4ca9-b234-75ef52ca2a2d','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','holmium content'),
    'f53a5dbc-3bd3-4570-adff-b00790ea3ffc': ('085af809-5dc6-4920-aaa1-4ac493ae4af8','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','nitrogen content'),
    '7980069a-3764-4d47-81b0-6cd0b79cc8f6': ('085af809-5dc6-4920-aaa1-4ac493ae4af8','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','Organic Nitrogen content of soil'),
    'cf66b969-7413-4ee7-aaf1-8a3b47904836': ('085af809-5dc6-4920-aaa1-4ac493ae4af8','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','concentration, nitrogen'),
    'f04a971d-f503-4ca0-b2b1-0ecd2e53ea61': ('085af809-5dc6-4920-aaa1-4ac493ae4af8','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, nitrogen'),
    '88c9f622-8451-41aa-98b0-c56b191a7e0a': ('085af809-5dc6-4920-aaa1-4ac493ae4af8','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, particulate nitrogen'),
    '1ae79861-a8a8-4118-aa6b-eb93351f315b': ('2e4695ff-d6a5-42c2-9816-6dbd6c859707','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, radium'),
    '8daf1327-bd94-4903-8e7b-5fe7731a259b': ('2e4695ff-d6a5-42c2-9816-6dbd6c859707','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','radium content'),
    '40a28310-9574-4867-88fb-623fa7ed1fa3': ('f3e1017d-1aa3-4763-b563-9494858e1ec7','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, hydrogen'),
    '2d23d1bb-e137-4ade-83fc-fbd0421e6cd5': ('f3e1017d-1aa3-4763-b563-9494858e1ec7','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','hydrogen content'),
    '76b0b954-ae61-4ac8-a585-700724fd53a6': ('078ecf46-26d6-47e3-8128-fcced884d1cd','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, germanium'),
    'fe9f0d92-ecdf-4e72-bd20-fadd3b6175bf': ('078ecf46-26d6-47e3-8128-fcced884d1cd','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','germanium content'),
    'cf6fc65c-b941-4211-89c8-ec3aec00b076': ('0bb4f3ac-2944-4263-8587-ea6eac2d24ac','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, rhenium'),
    '48b2521b-63f6-4121-9c3f-8edef7b31fc5': ('0bb4f3ac-2944-4263-8587-ea6eac2d24ac','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','rhenium content'),
    '33976f6b-2575-4410-8f60-d421bdf3e554': ('5db5be2d-8df6-432b-ab3d-ffde49d3fe7f','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, barium'),
    '1dcfb203-7830-40b2-878d-13fc02a74051': ('5db5be2d-8df6-432b-ab3d-ffde49d3fe7f','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','barium content'),
    '9adea776-5feb-432f-8f16-34d78ed99306': ('9bb58775-7ba8-41a7-8818-f75af4f5fe39','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, platinum'),
    '832bb926-0c7d-4b16-bf36-fc69665afe8b': ('9bb58775-7ba8-41a7-8818-f75af4f5fe39','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','platinum content'),
    'c35265a9-fd3e-468c-af8e-f4e020c38fc0': ('71fc82ec-9eb9-424a-bc45-053a844c8af9','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, selenium'),
    '7e83fd10-c04d-4a80-8df2-a8bbcc268c4a': ('71fc82ec-9eb9-424a-bc45-053a844c8af9','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','selenium content'),
    '4e0d51e1-8833-45e8-bd22-48292c8c93b8': ('7eb51190-01f0-40a0-801d-b5c588272314','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, krypton'),
    'aaedfd5e-a9ce-4257-a015-93ef483fed8c': ('7eb51190-01f0-40a0-801d-b5c588272314','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','krypton content'),
    'b142feef-d230-4376-aee7-919bbebed59a': ('d58f03c0-feab-4e47-aef6-4394aecc72dd','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration. lutetium'),
    'fbc58d8d-0a4c-4eb0-a14a-fafef222bafc': ('d58f03c0-feab-4e47-aef6-4394aecc72dd','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','lutetium content'),
    '6b7d0b77-c97b-4a8a-b4c5-f70836484a84': ('d7882bb5-cb4e-4ef6-84d8-1e1b75de022c','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, neon'),
    'fb2ccf7c-73c6-4d43-a3c7-26fda1423f18': ('d7882bb5-cb4e-4ef6-84d8-1e1b75de022c','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','neon content'),
    '807a3833-37fa-4606-9023-25d4e9eb0158': ('697fbcb6-b516-4c2f-a78e-5ec2ffaec4b3','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, caesium'),
    '4583f86d-51fa-4fda-9c75-7fba827532f5': ('697fbcb6-b516-4c2f-a78e-5ec2ffaec4b3','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','caesium content'),
    '2382a305-44cb-479c-a43d-f759f7689a9d': ('dccec68c-c1c9-42e4-9fa9-42dbb943082d','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','concentration, cadmium'),
    '1111ac7e-20df-4ab4-9e02-57821894372c': ('dccec68c-c1c9-42e4-9fa9-42dbb943082d','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, cadmium'),
    'ad7781c7-5dc2-4421-b182-e1fd4cef7fa5': ('dccec68c-c1c9-42e4-9fa9-42dbb943082d','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','cadmium content'),
    'edb5885b-2292-4889-9221-ab7012ea5595': ('5c39e9a9-4bb5-42cd-b519-0db3a940a575','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, ruthenium'),
    '44454aa6-3e54-4bb3-850c-9011a7257985': ('5c39e9a9-4bb5-42cd-b519-0db3a940a575','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','ruthenium content'),
    '5b7203d0-4a12-43e3-a2de-d9000584a5c6': ('2ea4d465-87e3-4f85-81a0-2bd661639f4e','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, yttrium'),
    '72ca3df5-6d2a-4a64-9fdf-d976136e4167': ('2ea4d465-87e3-4f85-81a0-2bd661639f4e','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','yttrium content'),
    'a3ca4324-b23e-489e-a799-b50ef9ed2e4e': ('d07d61ac-df46-4e74-bd49-3260c7b5fb89','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, protactinium'), # used ILCD Proactinium content
    '30fd0072-a0d4-4b5b-ad3e-dbd50a227ba5': ('d07d61ac-df46-4e74-bd49-3260c7b5fb89','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','protactinium content'), # used ILCD Proactinium content
    '8e73d3fb-bb81-4c42-bfa6-8be4ff13125d': ('699b6a73-e8d5-4755-8d1d-b70de4b9efdd','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, phophorus'), # Name has textual error
    '97f3bbfe-fa3a-4d05-9cb6-bb4b6379c5ef': ('699b6a73-e8d5-4755-8d1d-b70de4b9efdd','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','phosphorus content'),
    '449f4414-9f9f-4b76-8bfb-f170052555ab': ('699b6a73-e8d5-4755-8d1d-b70de4b9efdd','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','concentration, phosphorus'),
    '0f205308-d33a-430b-b3ec-b62bef311f2f': ('699b6a73-e8d5-4755-8d1d-b70de4b9efdd','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, particulate phophorus'), # Name has textual error
    '6a158827-67f6-4c5e-ba04-3da10718fc21': ('d703ed04-22ca-4151-85ae-da1fcf54df68','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, niobium'),
    'd8135201-fa30-4332-a051-7eddb3f8f8ed': ('d703ed04-22ca-4151-85ae-da1fcf54df68','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','niobium content'),
    '26ec2bdf-c4d7-4ed4-a751-5cfa97d2b26b': ('61ec59a5-3816-4e5a-88c7-acf8a8b33d41','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','concentration, silver'),
    'dcdc6c7b-0b72-4174-bc90-f51ed66426d5': ('61ec59a5-3816-4e5a-88c7-acf8a8b33d41','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, silver'),
    '56f09738-8225-4bdc-91d2-39ee6328f0ee': ('61ec59a5-3816-4e5a-88c7-acf8a8b33d41','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','silver content'),
    'dfe0e5ee-314c-4fac-9a75-c96aa63ec3b5': ('184c9c12-32fb-4252-a484-9952928b8473','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','concentration, indium'),
    'cbffa34c-c6de-4836-abfe-c6b94b99655a': ('184c9c12-32fb-4252-a484-9952928b8473','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, indium'),
    'd0a2c761-50ab-4c1d-a37b-525409640a76': ('184c9c12-32fb-4252-a484-9952928b8473','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','indium content'),
    '763a698f-54d7-4e2a-84a7-9cc8c0271b6a': ('476dbccb-c1e5-4cdb-aa14-f4ef627c45ec','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, fluorine'),
    '1f3c2d02-f345-4df9-ba6a-88cdeaa67923': ('476dbccb-c1e5-4cdb-aa14-f4ef627c45ec','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','fluorine content'),
    '9210d4a4-402c-475a-b354-94a8263632eb': ('1e6e8252-dae9-4b4a-866c-c6c3a5e810a1','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, thulium'),
    'fdafa860-c059-437e-838d-9d151b2067b3': ('1e6e8252-dae9-4b4a-866c-c6c3a5e810a1','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','thulium content'),
    '77154d2e-4b05-48f2-a89a-789acd170497': ('d6b6a36c-58b3-48c7-b723-392a6df4754f','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, aluminium'),
    'e9688cbc-7400-457a-a936-5ab123ea326c': ('d6b6a36c-58b3-48c7-b723-392a6df4754f','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','aluminium content'),
    '2dd01d14-3b27-4a66-9308-2ab96e6bcbd0': ('24a07e87-aa12-4f9c-8c40-580e9bf7a2f2','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, zirconium'),
    'da9aed81-4e0a-4a15-9d5e-27020d826a01': ('24a07e87-aa12-4f9c-8c40-580e9bf7a2f2','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','zirconium content'),
    '6d9e1462-80e3-4f10-b3f4-71febd6f1168': ('7ec8d70e-4ffc-4024-86b7-6141cc0a2bf5','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','water in wet mass'),
    'a9358458-9724-4f03-b622-106eda248916': ('7ec8d70e-4ffc-4024-86b7-6141cc0a2bf5','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','water content'),
    '26e0e131-cb29-4602-9cce-ecaaf1ffd8d4': ('827934c0-561e-402c-82f2-f04765d180e5','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, bismuth'),
    'e66d61f6-8287-4cf1-bb0c-f978ee5e34b3': ('827934c0-561e-402c-82f2-f04765d180e5','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','bismuth content'),
    'd21c7c5c-b2c2-43ae-8575-c377cc0b0495': ('83040211-0076-4862-b172-79ce62b71187','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, beryllium'),
    'bf4d71d9-4301-4939-8a9d-36d8811b7db0': ('83040211-0076-4862-b172-79ce62b71187','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','beryllium content'),
    '1a3f7490-7944-4d5a-ae87-4133cd0f6eec': ('78b712c9-7f07-467f-b085-efee6067871b','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, osmium'),
    'bbf35356-1757-4287-a72c-ae2bb1753731': ('78b712c9-7f07-467f-b085-efee6067871b','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','osmium content'),
    'c0dd146d-4b11-4b59-bd42-01ab280d6342': ('85aa9476-64fb-4c86-bc01-0c656b479cb8','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, lithium'),
    'db0b4bbf-fd26-4ba2-b9de-0fd47476304f': ('85aa9476-64fb-4c86-bc01-0c656b479cb8','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','lithium content'),
    'ff888459-10c3-4700-afce-3a024aaf89cf': ('11f31f00-f6fa-4ef0-a9e3-5bd37199dd20','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, tin'),
    'd8551abf-da96-4429-846b-0973136b7d48': ('11f31f00-f6fa-4ef0-a9e3-5bd37199dd20','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','tin content'),
    'b41681b0-87c1-4333-8eae-045ec68fe0c2': ('25c2946d-2b1f-4245-b2aa-80c037912665','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, thorium'),
    'b181bebd-539c-49bc-810e-9a443060afbc': ('25c2946d-2b1f-4245-b2aa-80c037912665','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','thorium content'),
    '3a0030f4-0585-487f-84fb-c6f3fa283ade': ('f18a0b1c-59ec-4c76-ae20-bc6c522547b3','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, tellurium'),
    '8aaa7771-015a-4c28-8291-afa3342dbfbe': ('f18a0b1c-59ec-4c76-ae20-bc6c522547b3','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','tellurium content'),
    '70da437b-65cd-498b-a980-7a6b8bc2f525': ('f33b22c4-e0e7-4fa6-ae2b-246ecb0a16eb','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','concentration, nickel'),
    '8b574e85-ff07-46bf-a753-f1271299dcf7': ('f33b22c4-e0e7-4fa6-ae2b-246ecb0a16eb','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, nickel'),
    'f767b36f-62bf-4458-b694-ecbefd2ab970': ('f33b22c4-e0e7-4fa6-ae2b-246ecb0a16eb','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','nickel content'),
    'c0447419-7139-44fe-a855-ea71e2b78585': ('77f40806-2c54-4050-97d3-d1b61eb4b0c9','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, boron'),
    'b86d456d-a1dc-4468-a20e-b6a3f4701e32': ('77f40806-2c54-4050-97d3-d1b61eb4b0c9','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','boron content'),
    'fcc233d5-ea53-4b90-9e2c-5624032a4b95': ('bd9b36ca-8240-464a-bba0-01c5210a5b66','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','concentration, magnesium'),
    'd26c0a60-86aa-41c8-80ee-3acabc4a5095': ('bd9b36ca-8240-464a-bba0-01c5210a5b66','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, magnesium'),
    '8aedc313-f49b-42cd-8d54-fc877ec03017': ('bd9b36ca-8240-464a-bba0-01c5210a5b66','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','magnesium content'),
    '7b656e1b-bc07-41cd-bad4-a5b51b6287da': ('e1b01126-0456-41b5-a29a-d6bd5095b64b','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, sodium'),
    'd3c0b420-1906-478c-8812-acfe6bf40c2e': ('e1b01126-0456-41b5-a29a-d6bd5095b64b','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','sodium content'),
    'cc72d858-3a21-481e-8013-55a53976ffc2': ('0ac18236-1ef4-4d67-95c0-4aebfec7f470','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, cerium'),
    'ea0dd556-455f-4524-b594-785505f1c0af': ('0ac18236-1ef4-4d67-95c0-4aebfec7f470','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','cerium content'),
    'd271dd60-df24-4dbe-b447-7f059810a0f3': ('e57088b8-0313-45c4-b791-6fdfbb59a142','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, samarium'),
    '82728b89-48ab-4da6-9bad-faeb8ce02d1a': ('e57088b8-0313-45c4-b791-6fdfbb59a142','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','samarium content'),
    '5ec6019b-0773-4119-9d96-ed9355eaad80': ('d55035e1-5a9a-44c5-88ce-d20086ab7148','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, neodymium'),
    'a91695f7-22e8-4b39-bd05-56aacab09a87': ('d55035e1-5a9a-44c5-88ce-d20086ab7148','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','neodymium content'),
    '0b686a86-c506-4ad3-81fd-c3f39f05247d': ('7cc6f031-f747-49e0-9600-ce2a2fe5657e','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, vanadium'),
    'dba83ee6-9127-4c81-86c9-15e29987dcdf': ('7cc6f031-f747-49e0-9600-ce2a2fe5657e','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','vanadium content'),
    '28841901-be10-4b4c-b077-228b4de6e7b1': ('83c2eede-677e-43ec-98c8-1d801c7f1774','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, xenon'),
    '59d14f7c-d6ea-4770-af4a-aa3dd6538b98': ('83c2eede-677e-43ec-98c8-1d801c7f1774','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','xenon content'),
    '6c113912-2ae5-4dea-99ea-1f0ebfe39c31': ('33cf4d9a-bcbf-4fe4-926b-38f2c3e36278','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, tantalum'),
    '43e30a6f-82ee-4f81-b799-e835163c8dcd': ('33cf4d9a-bcbf-4fe4-926b-38f2c3e36278','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','tantalum content'),
    '2584546f-187b-4a1d-b246-0af9d354b46b': ('b1dd578a-f16a-4eaa-ae08-442aa2a1a2de','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, helium'),
    '22ca28a0-51e6-4f82-9ae7-b6c22a59abb9': ('b1dd578a-f16a-4eaa-ae08-442aa2a1a2de','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','helium content'),
    'd717d3e6-7f87-4c07-b1af-9458e21efaa9': ('1d85ab50-ed1e-4421-b3b8-c5197d858a0d','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','density argon'),
    'da1ed753-c185-4631-9cec-45d09fcec8f4': ('1d85ab50-ed1e-4421-b3b8-c5197d858a0d','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, argon'),
    'cd5814c6-01ff-4fe8-b4bc-225084393eb2': ('1d85ab50-ed1e-4421-b3b8-c5197d858a0d','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','argon content'),
    'effa47e4-3d54-4e54-8b92-223b790f544a': ('a0f29f45-108a-4aef-8a66-aef07ed34913','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','concentration, iron'),
    'ebf21bca-b7cf-45d0-9d82-bfb80519a970': ('a0f29f45-108a-4aef-8a66-aef07ed34913','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, iron'),
    'd8364dfc-5753-4585-bf50-4d42b126f72d': ('a0f29f45-108a-4aef-8a66-aef07ed34913','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','iron content'),
    'd8d0d9e1-d98a-4adb-ad4d-de0bb2a1deb3': ('e02ff80b-c3f1-4d9d-b33a-f8c3001c70b8','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, rhodium'),
    '92dbd49f-8cf0-4510-b9c0-6b90443b328e': ('e02ff80b-c3f1-4d9d-b33a-f8c3001c70b8','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','rhodium content'),
    '630eb01c-d5ad-45b2-896f-9228a893e6d8': ('e8b9419c-c36e-445f-a3a9-ace79156ac30','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, erbium'),
    'e092deec-37ab-4f20-ad74-1460544a9911': ('e8b9419c-c36e-445f-a3a9-ace79156ac30','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','erbium content'),
    '253644d1-9ec6-4373-bda4-afbdd248d5b1': ('7c367337-54f2-4fe9-8ee3-3f42681b0792','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','concentration, zinc'),
    '6cc518c8-4769-40df-b2cf-03f9fe00b759': ('7c367337-54f2-4fe9-8ee3-3f42681b0792','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, zinc'),
    '33f96fe7-39da-47ca-837f-f2c311681d1b': ('7c367337-54f2-4fe9-8ee3-3f42681b0792','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','zinc content'),
    'decbd998-dc69-4964-9f82-8b9d9ca93e91': ('aaa95528-e05d-4eb4-85ff-a5445b580dcc','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, oxygen'),
    'dbf41b1b-c7b8-4d5e-b39c-f858eb868df5': ('aaa95528-e05d-4eb4-85ff-a5445b580dcc','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','oxygen content'),
    'a4d1b0a4-a4ef-429e-9fab-6dd6ea142c37': ('b8ef5a2b-ed75-4497-a061-1ecbbd79a380','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, uranium'),
    '6b093a42-84fe-41a1-8488-0fb444a5cf9d': ('b8ef5a2b-ed75-4497-a061-1ecbbd79a380','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','uranium content'),
    'adafb091-8daa-4bc9-b302-98aa221ff337': ('2651cd57-1c24-4b8e-856b-ddb63a3b267e','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','concentration, mercury'),
    'a102e6f8-ebc7-450b-a39b-794be96558b7': ('2651cd57-1c24-4b8e-856b-ddb63a3b267e','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, mercury'),
    '2a256b0b-6003-4669-a3c1-1d3eba2de45e': ('2651cd57-1c24-4b8e-856b-ddb63a3b267e','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mercury content'),
    '2d99e421-b9bd-4e09-98e4-f09478190a9b': ('b7be6dba-97f0-42f6-b173-e2c6b042fbe7','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','concentration, sulfur'),
    '8175120e-a5b7-4f19-afca-5620e9e4dd8b': ('b7be6dba-97f0-42f6-b173-e2c6b042fbe7','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, particulate sulfur'),
    '7f3410da-b91e-40d8-9545-ab269ff66900': ('b7be6dba-97f0-42f6-b173-e2c6b042fbe7','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, sulfur'),
    'f6c7ebbb-902a-412f-a55b-0743aea00238': ('b7be6dba-97f0-42f6-b173-e2c6b042fbe7','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','sulfur content'),
    'e4504511-88b5-4b01-a537-e049f056668c': ('d4f76a48-d1c9-4c49-a46e-b61feb974ac4','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, bromine'),
    '6b90d16b-f20b-4b53-abc2-763f9455dc05': ('d4f76a48-d1c9-4c49-a46e-b61feb974ac4','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','bromine content'),
    '058d6d50-172b-4a8a-97da-0cee759eca7d': ('825ef2f3-f706-4c47-8f8d-ee9ddbab3b43','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, tungsten'), # Radon content not considered (it is different that radium) 74f8559d-44a4-409f-9316-a185882a496c
    '84916b80-bf93-4e20-9b7c-593aa9518d09': ('825ef2f3-f706-4c47-8f8d-ee9ddbab3b43','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','tungsten content'),
    '3e1978a6-47f8-4e31-8a83-79053a0e715e': ('fa94ba11-2720-441d-b432-a2774f3ab1ad','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, gold'),
    'ee301bc4-052a-40c2-a5d7-76fa6e429aa5': ('fa94ba11-2720-441d-b432-a2774f3ab1ad','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','gold content'),
    'e38c9209-6934-4445-b180-675bcbd5ad7a': ('6827435e-8ad9-44c1-b0b4-b26f321957b1','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','concentration, potassium'),
    '8b49eeb7-9caf-4101-b516-eb0aef30d530': ('6827435e-8ad9-44c1-b0b4-b26f321957b1','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, potassium'),
    'ca949a93-0642-4d1d-83bf-52faf10f2329': ('6827435e-8ad9-44c1-b0b4-b26f321957b1','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','potassium content'),
    '79baac3d-9e62-45ef-8f41-440dea32f11f': ('b8a29b5f-1e7e-4f15-881f-e802e42551eb','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, thallium'),
    '608190bf-8f74-4f8e-8544-f25377accf4d': ('b8a29b5f-1e7e-4f15-881f-e802e42551eb','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','thallium content'),
    'e9164ff3-fd2d-4050-895d-0e0a42317be2': ('02f11c31-4bb8-41de-81fb-fb479f361eb9','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, iodine'),
    'b3026066-b632-4c47-a27e-c13f4a3489fb': ('02f11c31-4bb8-41de-81fb-fb479f361eb9','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','iodine content'),
    'abc78955-bd5f-4b1a-9607-0448dd75ebf2': ('282882cf-a5e5-4170-82dd-8e84da2724d2','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, titanium'),
    'e9fa11a1-1011-421d-aa34-0544d767a632': ('282882cf-a5e5-4170-82dd-8e84da2724d2','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','titanium content'),
    'b321f120-4db7-4e7c-a196-82a231023052': ('cefa9508-86b9-4fad-824e-bbf9d6fdd6f9','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, arsenic'),
    '30f0aa15-2d50-4f09-af94-683b6dd68adc': ('cefa9508-86b9-4fad-824e-bbf9d6fdd6f9','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','arsenic content'),
    '98f985da-d0b2-4325-af0c-9e421a2ba950': ('ab654e01-766b-411b-8902-cd6a9c40e55e','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, palladium'),
    '999af43a-1a83-4231-ba3c-600b1941b3a0': ('ab654e01-766b-411b-8902-cd6a9c40e55e','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','palladium content'),
    '9a08745d-e89e-477c-81a9-2ea81a44547c': ('0ab79a5f-7fd7-4d5d-be55-559292c958d3','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','concentration, copper'),
    'e7451d8a-77af-44e0-86cf-ccd17ac84509': ('0ab79a5f-7fd7-4d5d-be55-559292c958d3','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, copper'),
    '0132d97c-5f19-4397-9197-59ab801b10cf': ('0ab79a5f-7fd7-4d5d-be55-559292c958d3','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','copper content'),
    'aa897226-0a91-40e5-aa05-4bae3b9e4213': ('92f2d417-544a-4fd1-bde7-25967ef93586','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, molybdenum'),
    '83f67a9e-bf78-4e0d-b1f0-5051a1fda9fe': ('92f2d417-544a-4fd1-bde7-25967ef93586','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','molybdenum content'),
    '69394b67-d859-4887-a7a2-64dec0ecdbd8': ('037f9009-8b06-470d-a190-21448f7921c7','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','concentration, lead'),
    '71bc04b9-abfe-4f30-ab8f-ba654c7ad296': ('037f9009-8b06-470d-a190-21448f7921c7','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, lead'),
    'e5507d89-78ad-4746-900c-b9afa5a62ea6': ('037f9009-8b06-470d-a190-21448f7921c7','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','lead content'),
    '291c5be3-dd62-4e12-a0bd-48c3e694169a': ('935e0cbe-3369-4537-8019-4157cf929304','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, terbium'),
    'ff25f3c3-5f43-4ac0-bb13-d8ecc6fc7b75': ('935e0cbe-3369-4537-8019-4157cf929304','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','terbium content'),
    '8d27623b-147c-44e8-93cc-2183eac22991': ('5a2556bf-a9ec-4720-9253-d40f1de3c2b8','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, manganese'),
    '2bc683e4-3780-4f00-8c1d-fd53e05cfde7': ('5a2556bf-a9ec-4720-9253-d40f1de3c2b8','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','manganese content'),
    '71ff1af9-6834-46e8-b392-e73cbe898dae': ('0b12d18f-0c7c-44da-8c52-dc3278f917c7','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, ytterbium'),
    '65387d28-9b09-44d2-9908-663c18b740a3': ('0b12d18f-0c7c-44da-8c52-dc3278f917c7','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','ytterbium content'),
    'ed62dbf5-82e7-4432-ac6a-9be3172c41fd': ('e4225227-7855-41ce-ba57-a5314fdcdcf1','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, gadolinium'),
    'f576f1a0-d669-4063-9309-82c4af778bb4': ('e4225227-7855-41ce-ba57-a5314fdcdcf1','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','gadolinium content'),
    '67065577-4705-4ece-a892-6dd1d7ecd1e5': ('607a33e0-28ed-42f8-ac8c-66f0c9700e56','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, silicon'),
    'dd7e15dc-c438-43f7-9c0d-d0a627163cf1': ('607a33e0-28ed-42f8-ac8c-66f0c9700e56','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','silicon content'),
    'e629f248-28bc-40c8-a7e8-f1c216e7eb1d': ('98eec5a0-44db-411a-a502-95139090bc61','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','mass concentration, iridium'),
    '0650a63d-be1c-49b6-94c5-d0dc2acc35d6': ('98eec5a0-44db-411a-a502-95139090bc61','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','iridium content'),
    'b3fdadf7-9e1d-42bd-b36c-1744c7565539': ('b3f0f892-c5a3-4c66-a432-c09e3d1e9bd6','59f191d6-5dd3-4553-af88-1a32accfe308','03.00.003','lifetime capacity [kg*day]'),
    '46971dec-a716-4891-a5b7-5bebce5f3cdf': ('838aaa20-0117-11db-92e3-0800200c9a66','838aaa21-0117-11db-92e3-0800200c9a66','03.00.000','lifetime capacity [metric ton*km]'),
    '38583c32-c20b-4553-9152-b14b0bee1e61': ('93a60a56-a3c8-11da-a746-0800200b9a66','93a60a57-a4c8-11da-a746-0800200c9a66','03.00.003','lifetime capacity [kg]'),
    'aefe9fab-ed23-4060-a35d-d24d5281926c': ('93a60a56-a3c8-22da-a746-0800200c9a66','93a60a57-a3c8-12da-a746-0800200c9a66','03.00.003','lifetime capacity [l]'),
    '93bfda45-49f5-44bd-beb0-91b38dde4035': ('c0447923-0e60-4b3c-97c2-a86dddd9eea5','af638906-3ec7-4314-8de7-f76039f2dd01','03.00.000','lifetime capacity [h]'),
    'ec1f2209-1f53-40d5-bc53-67f388c82f5a': ('93a60a56-a3c8-11da-a746-0800200c9a66','93a60a57-a3c8-11da-a746-0800200c9a66','03.00.003','lifetime capacity [kWh]'),
    '11d072f8-37fc-41c2-80b2-ebba4f301b49': ('93a60a56-a3c8-11da-a746-0800200c9a66','93a60a57-a3c8-11da-a746-0800200c9a66','03.00.003','lifetime capacity [MJ]'),
    'a01597eb-34e2-4057-a7c7-e27bfdca34d1': ('93a60a56-a3c8-22da-a746-0800200c9a66','93a60a57-a3c8-12da-a746-0800200c9a66','03.00.003','lifetime capacity in m3'),
    '5b66c906-de94-4a06-9037-498de5498f82': ('01846770-4cfe-4a25-8ad9-919d8d378345','5beb6eed-33a9-47b8-9ede-1dfe8f679159','03.00.004','lifetime capacity'),
    '350b57a1-2b58-49e8-96bd-c9a4be6b4625': ('01846770-4cfe-4a25-8ad9-919d8d378345','5beb6eed-33a9-47b8-9ede-1dfe8f679159','03.00.004','lifetime capacity [unit]'),
    '964f8b50-ce16-4364-835a-a3db5fb760b0': ('c0447923-0e60-4b3c-97c2-a86dddd9eea5','af638906-3ec7-4314-8de7-f76039f2dd01','03.00.000','lifetime'),
    }

# Dict with keys being uuid bound to a ilcd flow property and value equal to 
#   the default unit uuid of ECS2

ilcd_to_ecs2_un = {
    '1acf7c0f-aa9d-4022-a4b7-fe0b54ea0b91': ('329b50e2-c594-39e9-953c-04c61d81d61e','Items*a'),
    '01846770-4cfe-4a25-8ad9-919d8d378345': ('5b972631-34e3-4db7-a615-f6931770a0cb','unit'),
    '93a60a56-a3c8-11da-a746-0800200c9a66': ('980b811e-3905-4797-82a5-173f5568bc7e','MJ', 'NET'), # NET
    '93a60a56-a3c8-14da-a746-0800200c9a66': ('980b811e-3905-4797-82a5-173f5568bc7e','MJ','GROSS'), # GROSS
    '93a60a56-a3c8-22da-a746-0800200c9a66': ('de5b3c87-0e35-4fb0-9765-4f3ba34c99e5','m3'),
    '838aaa20-0117-11db-92e3-0800200c9a66': ('2f4daad7-5331-4f14-930c-d8bca924557d','metric ton*km'),
    '838aaa23-0117-11db-92e3-0800200c9a66': ('f2aaa4ba-fb58-49a7-a552-e7f64366f379','m'),
    '1cc347a0-3bd1-46db-a308-2707c68d2351': ('0e6f38bc-51be-4382-802d-1f389a88e589','person*km'),
    '93a60a56-a3c8-17da-a746-0800200c9a66': ('4923348e-591b-4772-b224-d19df86f04c9','kBq'),
    '93a60a56-a3c8-19da-a746-0800200c9a66': ('1017f68a-f818-4f9d-a34d-a31e7386f628','m2'),
    '93a60a56-a3c8-21da-a746-0800200c9a66': ('eb955b7c-7bed-401f-9c76-5db716ca3640','m2*year'),
    '441238a3-ba09-46ec-b35b-c30cfba746d1': ('481b9712-c417-44f1-bfba-38d58088173c','m3*year'),
    '93a60a56-a3c8-11da-a746-0800200b9a66': ('487df68b-4994-4027-8fdc-a4dc298257b7','kg'),
    'c0447923-0e60-4b3c-97c2-a86dddd9eea5': ('05af3809-c874-4611-a6e9-6c296385ec5d','day'),
    'e07b4169-bd86-4337-8fa6-1f76916475bf': ('8266bd67-ebd3-4d31-b972-eee3cf0da36f','m*year'),
    'f170abd3-f010-45f4-8e7c-9871a5c0421b': ('ca2f7f9a-ae4e-3c80-9388-b7bc26a8bf4d','mol'),
    '371b6515-6488-399b-9364-b9125dcf5ef2': ('ff8ed45d-bbfb-4531-8c7b-9b95e52bd41d','m3*km'),
    #'48af5f71-8255-32f8-a25d-cc668c7126e5': ('ef6ecb4d-863b-4cee-adb4-95076bded0a1','dimensionless'), # Dimensionless properties will not have an specific property
    '67b63204-ef91-44b2-a927-2f4ead1fae17': ('7b75baf0-cbee-45e6-bf66-af119da06553','EUR2005'),
    'b3f0f892-c5a3-4c66-a432-c09e3d1e9bd6': ('241450a3-3497-4648-8c68-e44d04f64ac7','kg*day'),
    '93a60a56-a3c8-13da-a746-0800200c9a66': ('de5b3c87-0e35-4fb0-9765-4f3ba34c99e5','m3'), # Normal Volume
    
    }
    
# Dict with keys as ILCD flow property UUIDs and values as
#   (ECS2 best equivalence UUID, name, additional function, (secondary possibilities for /kg and /m³))
# Units ans unit ids are gathered inside the additional function

ilcd_to_ecs2_fp = {
    '67b63204-ef91-44b2-a927-2f4ead1fae17': ('7b75baf0-cbee-45e6-bf66-af119da06553', 'EUR2005',
                                             '38f94dd1-d5aa-41b8-b182-c0c42985d9dc', 'price',
                                             (None, None)),
    '9b784a67-fbb1-4ad2-8774-30c39643b844': ('980b811e-3905-4797-82a5-173f5568bc7e', 'MJ',
                                             '48c987bb-3144-4872-b5c7-b1389c40be25', 'heating value, net',
                                             (None, None)),
    '93a60a56-a3c8-14da-a746-0800200c9a66': ('980b811e-3905-4797-82a5-173f5568bc7e', 'MJ',
                                             'd61b8768-8ef6-4a99-ae16-9e51f24ad5b5', 'heating value, gross',
                                             (None, None)),
    '93a60a56-a3c8-11da-a746-0800200c9a66': ('980b811e-3905-4797-82a5-173f5568bc7e', 'MJ',
                                             '48c987bb-3144-4872-b5c7-b1389c40be25', 'heating value, net',
                                             (None, None)),
    'f2149ae0-b105-4299-b1f1-cf1fd1577867': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'e1d2c19b-3a97-4f52-a83f-fe88400452c2', 'chromium content',
                                             (('ed229b01-1b3f-4754-8871-5e88a83f3725', 'concentration, chromium'),
                                              ('bca4bb32-f701-46bb-ba1e-bad477c19f7f', 'mass concentration, chromium'))),
    'ac557972-7563-49fb-8461-29a4fe8600b7': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'a17f5864-6177-4619-82c5-3426c8c64e7d', 'gallium content',
                                             (None, ('35d16e49-9e29-4e1d-ac22-ea7f84fb76e1', 'mass concentration, gallium'))),
    'b1192e5a-4a70-4fd7-89a2-6b798c7ed3a7': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '66e996b5-5f7b-449f-8893-0b787af21d7e', 'cobalt content',
                                             (None, ('2f7030b9-bafc-4b43-8504-deb8b5044130', 'mass concentration, cobalt'))),
    'a5278d68-2936-477b-b9de-7ad2d66422ec': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '995265a2-f2cb-4c12-a961-766eb34392b9', 'strontium content',
                                             (None, ('d574cc22-07f2-4202-b564-1116ab197692', 'mass concentration, strontium'))),
    'dd77d131-c2ee-4d5a-b5d3-f7aa981ae305': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '35d2e0b2-eca5-4897-a6af-b6d2e61a9079', 'scandium content',
                                             (None, ('1325d7f9-2fe2-4226-9304-ad9e5371e08f', 'mass concentration, scandium'))),
    '435e1d0e-e36e-4d4a-9cd1-7fd2c135da61': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '4054bfa7-dfcb-452e-b1dd-810b9e981506', 'antimony content',
                                             (None, ('3759d833-560a-4dbb-949e-afc63c0ade26', 'mass concentration, antimony'))),
    'c2a5d679-93be-44a1-b82f-da986e622ab9': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '0b27405b-3e4d-45aa-bb5c-3c52d2b04e0e', 'europium content',
                                             (None, ('a7e81e5c-d3b9-421c-bf6f-7cafcf911ab7', 'mass concentration, europium'))),
    '7eb6e3cb-0c12-4216-99b5-2032906d42ca': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '94b2be61-35f2-40fb-b9ab-636ae5a0415b', 'lanthanum content',
                                             (None, ('d33e6732-d2f8-4441-ba03-e39d4a1228a5', 'mass concentration, lanthanum'))),
    'fec15e58-109a-4775-bc6f-72ca0b9b3cee': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'a301a838-7975-4d89-9e74-8eb77ad03cd1', 'carbon content',
                                             (None, ('a301a838-7975-4d89-9e74-8eb77ad03cd1', 'mass concentration, carbone dioxide'))),
    '64b8e725-b0ba-4837-abb9-62dc0e7b9f6f': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'c74c3729-e577-4081-b572-a283d2561a75', 'carbon content, fossil',
                                             (None, None)), # Not considered the mass concentration of carbon since the distinction is not maintained
    '62e503ce-544a-4599-b2ad-bcea15a7bf20': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '6393c14b-db78-445d-a47b-c0cb866a1b25', 'carbon content, non-fossil',
                                             (None, None)),
    'b539c404-ce19-43fb-ba14-6a1bdd46d8be': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '4fb17587-2c03-4b4e-b38b-867cfd4bfae8', 'praseodymium content',
                                             (None, ('1ced5983-2a7b-49af-b6cd-ad4ebaafba89', 'mass concentration, praseodymium'))),
    '76d611d0-a0a5-43d5-b391-a4e7ec463052': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless',
                                             'f9da385d-5b1b-4548-826c-0bf5892a9fd9', 'calcium content',
                                             (('cea619b8-1a76-4680-8b55-cdf682a3b32a', 'concentration, calcium'),
                                              ('ddbab0d1-b156-41bc-98e5-fb680285d7cd', 'mass concentration, calcium'))),
    '984505b9-8536-4e31-a312-0d1a3788f009': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '66d4c921-658a-4ba0-b190-c6e09e57d74a', 'chlorine content',
                                             (None, ('468e50e8-1960-4eba-bc1a-a9938a301694', 'mass concentration, chlorine'))),
    '3da87ad0-733e-4ca9-b234-75ef52ca2a2d': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless',
                                             '86937b4e-c531-4ce5-b65e-ce0d17d3ca27', 'holmium content',
                                             (None, ('f0e05731-4b64-4a8a-a216-a7ad908d76bc', 'mass concentration, holmium'))),
    '085af809-5dc6-4920-aaa1-4ac493ae4af8': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'f53a5dbc-3bd3-4570-adff-b00790ea3ffc', 'nitrogen content',
                                             (('cf66b969-7413-4ee7-aaf1-8a3b47904836', 'concentration, nitrogen'),
                                              ('f04a971d-f503-4ca0-b2b1-0ecd2e53ea61', 'mass concentration, nitrogen'))),
    '2e4695ff-d6a5-42c2-9816-6dbd6c859707': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '8daf1327-bd94-4903-8e7b-5fe7731a259b', 'radium content',
                                             (None, ('1ae79861-a8a8-4118-aa6b-eb93351f315b', 'mass concentration, radium'))),
    'f3e1017d-1aa3-4763-b563-9494858e1ec7': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '2d23d1bb-e137-4ade-83fc-fbd0421e6cd5', 'hydrogen content',
                                             (None, ('40a28310-9574-4867-88fb-623fa7ed1fa3', 'mass concentration, hydrogen'))),
    '078ecf46-26d6-47e3-8128-fcced884d1cd': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless',
                                             'fe9f0d92-ecdf-4e72-bd20-fadd3b6175bf', 'germanium content',
                                             (None, ('76b0b954-ae61-4ac8-a585-700724fd53a6', 'mass concentration, germanium'))),
    '0bb4f3ac-2944-4263-8587-ea6eac2d24ac': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '48b2521b-63f6-4121-9c3f-8edef7b31fc5', 'rhenium content',
                                             (None, ('cf6fc65c-b941-4211-89c8-ec3aec00b076', 'mass concentration, rhenium'))),
    '5db5be2d-8df6-432b-ab3d-ffde49d3fe7f': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '1dcfb203-7830-40b2-878d-13fc02a74051', 'barium content',
                                             (None, ('33976f6b-2575-4410-8f60-d421bdf3e554', 'mass concentration, barium'))),
    '9bb58775-7ba8-41a7-8818-f75af4f5fe39': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '832bb926-0c7d-4b16-bf36-fc69665afe8b', 'platinum content',
                                             (None, ('9adea776-5feb-432f-8f16-34d78ed99306', 'mass concentration, platinum'))),
    '71fc82ec-9eb9-424a-bc45-053a844c8af9': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '7e83fd10-c04d-4a80-8df2-a8bbcc268c4a', 'selenium content',
                                             (None, ('c35265a9-fd3e-468c-af8e-f4e020c38fc0', 'mass concentration, selenium'))),
    '7eb51190-01f0-40a0-801d-b5c588272314': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'aaedfd5e-a9ce-4257-a015-93ef483fed8c', 'krypton content',
                                             (None, ('4e0d51e1-8833-45e8-bd22-48292c8c93b8', 'mass concentration, krypton'))),
    'd58f03c0-feab-4e47-aef6-4394aecc72dd': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'fbc58d8d-0a4c-4eb0-a14a-fafef222bafc', 'lutetium content',
                                             (None, ('b142feef-d230-4376-aee7-919bbebed59a', 'mass concentration, lutetium'))),
    'd7882bb5-cb4e-4ef6-84d8-1e1b75de022c': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'fb2ccf7c-73c6-4d43-a3c7-26fda1423f18', 'neon content',
                                             (None, ('6b7d0b77-c97b-4a8a-b4c5-f70836484a84', 'mass concentration, neon'))),
    '697fbcb6-b516-4c2f-a78e-5ec2ffaec4b3': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '4583f86d-51fa-4fda-9c75-7fba827532f5', 'caesium content',
                                             (None, ('807a3833-37fa-4606-9023-25d4e9eb0158', 'mass concentration, caesium'))),
    'dccec68c-c1c9-42e4-9fa9-42dbb943082d': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'ad7781c7-5dc2-4421-b182-e1fd4cef7fa5', 'cadmium content',
                                             (('2382a305-44cb-479c-a43d-f759f7689a9d', 'concentration, cadmium'),
                                              ('1111ac7e-20df-4ab4-9e02-57821894372c', 'mass concentration, cadmium'))),
    '5c39e9a9-4bb5-42cd-b519-0db3a940a575': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '44454aa6-3e54-4bb3-850c-9011a7257985', 'ruthenium content',
                                             (None, ('edb5885b-2292-4889-9221-ab7012ea5595', 'mass concentration, ruthenium'))),
    '2ea4d465-87e3-4f85-81a0-2bd661639f4e': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '72ca3df5-6d2a-4a64-9fdf-d976136e4167', 'yttrium content',
                                             (None, ('5b7203d0-4a12-43e3-a2de-d9000584a5c6', 'mass concentration, yttrium'))),
    'd07d61ac-df46-4e74-bd49-3260c7b5fb89': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '30fd0072-a0d4-4b5b-ad3e-dbd50a227ba5', 'protactinium content',
                                             (None, ('a3ca4324-b23e-489e-a799-b50ef9ed2e4e', 'mass concentration, protactinium'))),
    '699b6a73-e8d5-4755-8d1d-b70de4b9efdd': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '97f3bbfe-fa3a-4d05-9cb6-bb4b6379c5ef', 'phosphorus content',
                                             (('449f4414-9f9f-4b76-8bfb-f170052555ab', 'concentration, phophorus'),
                                              ('8e73d3fb-bb81-4c42-bfa6-8be4ff13125d', 'mass concentration, phophorus'))),
    'd703ed04-22ca-4151-85ae-da1fcf54df68': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'd8135201-fa30-4332-a051-7eddb3f8f8ed', 'niobium content',
                                             (None, ('6a158827-67f6-4c5e-ba04-3da10718fc21', 'mass concentration, niobium'))),
    '61ec59a5-3816-4e5a-88c7-acf8a8b33d41': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '56f09738-8225-4bdc-91d2-39ee6328f0ee', 'silver content',
                                             (('26ec2bdf-c4d7-4ed4-a751-5cfa97d2b26b', 'concentration, silver'),
                                              ('dcdc6c7b-0b72-4174-bc90-f51ed66426d5', 'mass concentration, silver'))),
    '184c9c12-32fb-4252-a484-9952928b8473': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'd0a2c761-50ab-4c1d-a37b-525409640a76', 'indium content',
                                             (('dfe0e5ee-314c-4fac-9a75-c96aa63ec3b5', 'concentration, indium'),
                                              ('cbffa34c-c6de-4836-abfe-c6b94b99655a', 'mass concentration, indium'))),
    '476dbccb-c1e5-4cdb-aa14-f4ef627c45ec': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '1f3c2d02-f345-4df9-ba6a-88cdeaa67923', 'fluorine content',
                                             (None, ('763a698f-54d7-4e2a-84a7-9cc8c0271b6a', 'mass concentration, fluorine'))),
    '1e6e8252-dae9-4b4a-866c-c6c3a5e810a1': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'fdafa860-c059-437e-838d-9d151b2067b3', 'thulium content',
                                             (None, ('9210d4a4-402c-475a-b354-94a8263632eb', 'mass concentration, thulium'))),
    'd6b6a36c-58b3-48c7-b723-392a6df4754f': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'e9688cbc-7400-457a-a936-5ab123ea326c', 'aluminium content',
                                             (None, ('77154d2e-4b05-48f2-a89a-789acd170497', 'mass concentration, aluminium'))),
    '24a07e87-aa12-4f9c-8c40-580e9bf7a2f2': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'da9aed81-4e0a-4a15-9d5e-27020d826a01', 'zirconium content',
                                             (None, ('2dd01d14-3b27-4a66-9308-2ab96e6bcbd0', 'mass concentration, zirconium'))),
    '7ec8d70e-4ffc-4024-86b7-6141cc0a2bf5': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'a9358458-9724-4f03-b622-106eda248916', 'water content',
                                             (None, None)), # Triggers water allocation calculations and content calculations
    '827934c0-561e-402c-82f2-f04765d180e5': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'e66d61f6-8287-4cf1-bb0c-f978ee5e34b3', 'bismuth content',
                                             (None, ('26e0e131-cb29-4602-9cce-ecaaf1ffd8d4', 'mass concentration, bismuth'))),
    '83040211-0076-4862-b172-79ce62b71187': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'bf4d71d9-4301-4939-8a9d-36d8811b7db0', 'beryllium content',
                                             (None, ('d21c7c5c-b2c2-43ae-8575-c377cc0b0495', 'mass concentration, beryllium'))),
    '78b712c9-7f07-467f-b085-efee6067871b': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'bbf35356-1757-4287-a72c-ae2bb1753731', 'osmium content',
                                             (None, ('1a3f7490-7944-4d5a-ae87-4133cd0f6eec', 'mass concentration, osmium'))),
    '85aa9476-64fb-4c86-bc01-0c656b479cb8': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'db0b4bbf-fd26-4ba2-b9de-0fd47476304f', 'lithium content',
                                             (None, ('c0dd146d-4b11-4b59-bd42-01ab280d6342', 'mass concentration, lithium'))),
    '11f31f00-f6fa-4ef0-a9e3-5bd37199dd20': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'd8551abf-da96-4429-846b-0973136b7d48', 'tin content',
                                             (None, ('ff888459-10c3-4700-afce-3a024aaf89cf', 'mass concentration, tin'))),
    '25c2946d-2b1f-4245-b2aa-80c037912665': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'b181bebd-539c-49bc-810e-9a443060afbc', 'thorium content',
                                             (None, ('b41681b0-87c1-4333-8eae-045ec68fe0c2', 'mass concentration, thorium'))),
    'f18a0b1c-59ec-4c76-ae20-bc6c522547b3': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '8aaa7771-015a-4c28-8291-afa3342dbfbe', 'tellurium content',
                                             (None, ('3a0030f4-0585-487f-84fb-c6f3fa283ade', 'mass concentration, tellurium'))),
    'f33b22c4-e0e7-4fa6-ae2b-246ecb0a16eb': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'f767b36f-62bf-4458-b694-ecbefd2ab970', 'nickel content',
                                             (('70da437b-65cd-498b-a980-7a6b8bc2f525', 'concentration, nickel'),
                                              ('8b574e85-ff07-46bf-a753-f1271299dcf7', 'mass concentration, nickel'))),
    '77f40806-2c54-4050-97d3-d1b61eb4b0c9': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'b86d456d-a1dc-4468-a20e-b6a3f4701e32', 'boron content',
                                             (None, ('c0447419-7139-44fe-a855-ea71e2b78585', 'mass concentration, boron'))),
    'bd9b36ca-8240-464a-bba0-01c5210a5b66': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '8aedc313-f49b-42cd-8d54-fc877ec03017', 'magnesium content',
                                             (('fcc233d5-ea53-4b90-9e2c-5624032a4b95', 'concentration, magnesium'),
                                              ('d26c0a60-86aa-41c8-80ee-3acabc4a5095', 'mass concentration, magnesium'))),
    'e1b01126-0456-41b5-a29a-d6bd5095b64b': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'd3c0b420-1906-478c-8812-acfe6bf40c2e', 'sodium content',
                                             (None, ('7b656e1b-bc07-41cd-bad4-a5b51b6287da', 'mass concentration, sodium'))),
    '0ac18236-1ef4-4d67-95c0-4aebfec7f470': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'ea0dd556-455f-4524-b594-785505f1c0af', 'cerium content',
                                             (None, ('cc72d858-3a21-481e-8013-55a53976ffc2', 'mass concentration, cerium'))),
    'e57088b8-0313-45c4-b791-6fdfbb59a142': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '82728b89-48ab-4da6-9bad-faeb8ce02d1a', 'samarium content',
                                             (None, ('d271dd60-df24-4dbe-b447-7f059810a0f3', 'mass concentration, samarium'))),
    'd55035e1-5a9a-44c5-88ce-d20086ab7148': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'a91695f7-22e8-4b39-bd05-56aacab09a87', 'neodymium content',
                                             (None, ('5ec6019b-0773-4119-9d96-ed9355eaad80', 'mass concentration, neodymium'))),
    '7cc6f031-f747-49e0-9600-ce2a2fe5657e': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'dba83ee6-9127-4c81-86c9-15e29987dcdf', 'vanadium content',
                                             (None, ('0b686a86-c506-4ad3-81fd-c3f39f05247d', 'mass concentration, vanadium'))),
    '83c2eede-677e-43ec-98c8-1d801c7f1774': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '59d14f7c-d6ea-4770-af4a-aa3dd6538b98', 'xenon content',
                                             (None, ('28841901-be10-4b4c-b077-228b4de6e7b1', 'mass concentration, xenon'))),
    '33cf4d9a-bcbf-4fe4-926b-38f2c3e36278': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '43e30a6f-82ee-4f81-b799-e835163c8dcd', 'tantalum content',
                                             (None, ('6c113912-2ae5-4dea-99ea-1f0ebfe39c31', 'mass concentration, tantalum'))),
    'b1dd578a-f16a-4eaa-ae08-442aa2a1a2de': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '22ca28a0-51e6-4f82-9ae7-b6c22a59abb9', 'helium content',
                                             (None, ('2584546f-187b-4a1d-b246-0af9d354b46b', 'mass concentration, helium'))),
    '1d85ab50-ed1e-4421-b3b8-c5197d858a0d': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'cd5814c6-01ff-4fe8-b4bc-225084393eb2', 'argon content',
                                             (None, ('da1ed753-c185-4631-9cec-45d09fcec8f4', 'mass concentration, argon'))),
    'a0f29f45-108a-4aef-8a66-aef07ed34913': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'd8364dfc-5753-4585-bf50-4d42b126f72d', 'iron content',
                                             (('effa47e4-3d54-4e54-8b92-223b790f544a', 'concentration, iron'),
                                              ('ebf21bca-b7cf-45d0-9d82-bfb80519a970', 'mass concentration, iron'))),
    'e02ff80b-c3f1-4d9d-b33a-f8c3001c70b8': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '92dbd49f-8cf0-4510-b9c0-6b90443b328e', 'rhodium content',
                                             (None, ('d8d0d9e1-d98a-4adb-ad4d-de0bb2a1deb3', 'mass concentration, rhodium'))),
    'e8b9419c-c36e-445f-a3a9-ace79156ac30': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'e092deec-37ab-4f20-ad74-1460544a9911', 'erbium content',
                                             (None, ('630eb01c-d5ad-45b2-896f-9228a893e6d8', 'mass concentration, erbium'))),
    '7c367337-54f2-4fe9-8ee3-3f42681b0792': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '33f96fe7-39da-47ca-837f-f2c311681d1b', 'zinc content',
                                             (('253644d1-9ec6-4373-bda4-afbdd248d5b1', 'concentration, zinc'),
                                              ('6cc518c8-4769-40df-b2cf-03f9fe00b759', 'mass concentration, zinc'))),
    'aaa95528-e05d-4eb4-85ff-a5445b580dcc': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'dbf41b1b-c7b8-4d5e-b39c-f858eb868df5', 'oxygen content',
                                             (None, ('decbd998-dc69-4964-9f82-8b9d9ca93e91', 'mass concentration, oxygen'))),
    'b8ef5a2b-ed75-4497-a061-1ecbbd79a380': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '6b093a42-84fe-41a1-8488-0fb444a5cf9d', 'uranium content',
                                             (None, ('a4d1b0a4-a4ef-429e-9fab-6dd6ea142c37', 'mass concentration, uranium'))),
    '2651cd57-1c24-4b8e-856b-ddb63a3b267e': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '2a256b0b-6003-4669-a3c1-1d3eba2de45e', 'mercury content',
                                             (('adafb091-8daa-4bc9-b302-98aa221ff337', 'concentration, mercury'),
                                              ('a102e6f8-ebc7-450b-a39b-794be96558b7', 'mass concentration, mercury'))),
    'b7be6dba-97f0-42f6-b173-e2c6b042fbe7': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'f6c7ebbb-902a-412f-a55b-0743aea00238', 'sulfur content',
                                             (('2d99e421-b9bd-4e09-98e4-f09478190a9b', 'concentration, sulfur'),
                                              ('7f3410da-b91e-40d8-9545-ab269ff66900', 'mass concentration, sulfur'))),
    'd4f76a48-d1c9-4c49-a46e-b61feb974ac4': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '6b90d16b-f20b-4b53-abc2-763f9455dc05', 'bromine content',
                                             (None, ('e4504511-88b5-4b01-a537-e049f056668c', 'mass concentration, bromine'))),
    '825ef2f3-f706-4c47-8f8d-ee9ddbab3b43': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '84916b80-bf93-4e20-9b7c-593aa9518d09', 'tungsten content',
                                             (None, ('058d6d50-172b-4a8a-97da-0cee759eca7d', 'mass concentration, tungsten'))),
    'fa94ba11-2720-441d-b432-a2774f3ab1ad': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'ee301bc4-052a-40c2-a5d7-76fa6e429aa5', 'gold content',
                                             (None, ('3e1978a6-47f8-4e31-8a83-79053a0e715e', 'mass concentration, gold'))),
    '6827435e-8ad9-44c1-b0b4-b26f321957b1': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'ca949a93-0642-4d1d-83bf-52faf10f2329', 'potassium content',
                                             (('e38c9209-6934-4445-b180-675bcbd5ad7a', 'concentration, potassium'),
                                              ('8b49eeb7-9caf-4101-b516-eb0aef30d530', 'mass concentration, potassium'))),
    'b8a29b5f-1e7e-4f15-881f-e802e42551eb': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '608190bf-8f74-4f8e-8544-f25377accf4d', 'thallium content',
                                             (None, ('79baac3d-9e62-45ef-8f41-440dea32f11f', 'mass concentration, thallium'))),
    '02f11c31-4bb8-41de-81fb-fb479f361eb9': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'b3026066-b632-4c47-a27e-c13f4a3489fb', 'iodine content',
                                             (None, ('e9164ff3-fd2d-4050-895d-0e0a42317be2', 'mass concentration, iodine'))),
    '282882cf-a5e5-4170-82dd-8e84da2724d2': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'e9fa11a1-1011-421d-aa34-0544d767a632', 'titanium content',
                                             (None, ('abc78955-bd5f-4b1a-9607-0448dd75ebf2', 'mass concentration, titanium'))),
    'cefa9508-86b9-4fad-824e-bbf9d6fdd6f9': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '30f0aa15-2d50-4f09-af94-683b6dd68adc', 'arsenic content',
                                             (None, ('b321f120-4db7-4e7c-a196-82a231023052', 'mass concentration, arsenic'))),
    'ab654e01-766b-411b-8902-cd6a9c40e55e': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '999af43a-1a83-4231-ba3c-600b1941b3a0', 'palladium content',
                                             (None, ('98f985da-d0b2-4325-af0c-9e421a2ba950', 'mass concentration, palladium'))),
    '0ab79a5f-7fd7-4d5d-be55-559292c958d3': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '0132d97c-5f19-4397-9197-59ab801b10cf', 'copper content',
                                             (('9a08745d-e89e-477c-81a9-2ea81a44547c', 'concentration, copper'),
                                              ('e7451d8a-77af-44e0-86cf-ccd17ac84509', 'mass concentration, copper'))),
    '92f2d417-544a-4fd1-bde7-25967ef93586': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '83f67a9e-bf78-4e0d-b1f0-5051a1fda9fe', 'molybdenum content',
                                             (None, ('aa897226-0a91-40e5-aa05-4bae3b9e4213', 'mass concentration, molybdenum'))),
    '037f9009-8b06-470d-a190-21448f7921c7': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'e5507d89-78ad-4746-900c-b9afa5a62ea6', 'lead content',
                                             (('69394b67-d859-4887-a7a2-64dec0ecdbd8', 'concentration, lead'),
                                              ('71bc04b9-abfe-4f30-ab8f-ba654c7ad296', 'mass concentration, lead'))),
    '935e0cbe-3369-4537-8019-4157cf929304': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'ff25f3c3-5f43-4ac0-bb13-d8ecc6fc7b75', 'terbium content',
                                             (None, ('291c5be3-dd62-4e12-a0bd-48c3e694169a', 'mass concentration, terbium'))),
    '5a2556bf-a9ec-4720-9253-d40f1de3c2b8': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '2bc683e4-3780-4f00-8c1d-fd53e05cfde7', 'manganese content',
                                             (None, ('8d27623b-147c-44e8-93cc-2183eac22991', 'mass concentration, manganese'))),
    '0b12d18f-0c7c-44da-8c52-dc3278f917c7': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             '65387d28-9b09-44d2-9908-663c18b740a3', 'ytterbium content', 
                                             (None, ('71ff1af9-6834-46e8-b392-e73cbe898dae', 'mass concentration, ytterbium'))),
    'e4225227-7855-41ce-ba57-a5314fdcdcf1': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'f576f1a0-d669-4063-9309-82c4af778bb4', 'gadolinium content', 
                                             (None, ('ed62dbf5-82e7-4432-ac6a-9be3172c41fd', 'mass concentration, gadolinium'))),
    '607a33e0-28ed-42f8-ac8c-66f0c9700e56': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless', 
                                             'dd7e15dc-c438-43f7-9c0d-d0a627163cf1', 'silicon content', 
                                             (None, ('67065577-4705-4ece-a892-6dd1d7ecd1e5', 'mass concentration, silicon'))),
    '98eec5a0-44db-411a-a502-95139090bc61': ('577e242a-461f-44a7-922c-d8e1c3d2bf45', 'dimensionless',
                                             '0650a63d-be1c-49b6-94c5-d0dc2acc35d6', 'iridium content',
                                             (None, ('e629f248-28bc-40c8-a7e8-f1c216e7eb1d', 'mass concentration, iridium')))
    }
